@@ -6,4 +6,6 @@
 # All rights reserved.
 # -------------------------------
 
-# Juniper CS is a Package intended to be executed from its inner Main Script
\ No newline at end of file
+from .juniper_source import *
+#from .ply.lex import *
+#from .ply.yacc import *
\ No newline at end of file
