@@ -8,8 +8,8 @@
 
 # Packages
 
-import ply.lex as lex
-import ply.yacc as yacc
+from .ply import lex as lex
+from .ply import yacc as yacc
 import sys 
 import os # delete
 
